@@ -5,10 +5,10 @@ from graphene_django.types import DjangoObjectType
 # Standard/core python libraries
 # Our custom libraries
 
-# EXAMPLE GRAPHENE ObjectType
+# EXAMPLE GRAPHENE ObjectType (Managed by SPRINGLABS_DJANGO)
 
 
-class UserType(graphene.ObjectType):
+class ExampleDjangoType(graphene.ObjectType):
     id_user = graphene.ID(description="A unique int value identifying User",
         required=False)
     username = graphene.String(description="A unique string value identifying User",
@@ -23,14 +23,4 @@ class UserType(graphene.ObjectType):
     class Meta:
         name = "User"
         description = "Manejo de Usuarios"
-
-# EXAMPLE GRAPHENE DjangoObjectType
-# class PortType(DjangoObjectType):
-#     class Meta:
-#         name = "Name"
-#         description = "Description name"
-#         model = Model
-#         fields = ["field_1",
-#                   "field_2",
-#                   "field_3",
-#                   ]
+# END EXAMPLE GRAPHENE ObjectType (Managed by SPRINGLABS_DJANGO)
