@@ -61,7 +61,19 @@ def createVersion(version, project_name, old_versions):
     else:
         objVersionDetail = {
             "version": version,
-            "groups": ["users"]
+            "groups": ["users"],
+            "groups_detail": [
+                {
+                    "group": "users",
+                    "apis": [],
+                    "graph": [
+                        {
+                            "graph_name": "ExampleDjango",
+                            "graph_type" : "open"
+                        }
+                    ]
+                }
+            ]
         }
         data["versions"].append(version)
         data['versions_detail'].append(objVersionDetail)
